<!DOCTYPE kpartgui>
<kpartgui name="kcontrol" version="2">
<MenuBar>
    <Menu name="view"><text>&amp;View</text>
        <Menu name="view_mode"><text>&amp;Mode</text>
            <Action name="activate_iconview"/>
            <Action name="activate_treeview"/>
        </Menu>
        <Menu name="view_iconsize"><text>Icon &amp;Size</text>
            <Action name="activate_smallicons"/>
            <Action name="activate_mediumicons"/>
            <Action name="activate_largeicons"/>
            <Action name="activate_hugeicons"/>
        </Menu>
    </Menu>
    <Menu name="help">
        <Action name="help_about_module" append="about_merge"/>
    </Menu>
</MenuBar>
</kpartgui>
