<!DOCTYPE kpartgui>
<kpartgui name="ksysguard" version="5">
<State name="showProcessState">
  <Disable>
    <Action name="file_new"/>
    <Action name="file_open"/>
    <Action name="file_open_recent"/>
    <Action name="file_close"/>
    <Action name="file_revert"/>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
    <Action name="edit_copy"/>
    <Action name="edit_cut"/>
    <Action name="edit_paste"/>
    <Action name="configure_sheet"/>
    <Action name="configure_style"/>
  </Disable>
</State>
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="configure_sheet"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="configure_style"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
    <Action name="file_new"/>
    <Action name="file_open"/>
    <Action name="file_save"/>
    <Separator/>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
    <Separator/>
    <Action name="edit_copy"/>
    <Action name="edit_cut"/>
    <Action name="edit_paste"/>
    <Separator/>
    <Action name="configure_sheet"/>
    <Action name="configure_style"/>
</ToolBar>
</kpartgui>
