<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kcontroledit" version="4">

<MenuBar>

<Menu name="file" noMerge="1"><text>&amp;File</text>
 <Action name="newitem"/>
 <Action name="newsubmenu" />
 <Separator/>
 <Action name="file_save"/>
 <Separator/>
 <Action name="file_quit"/>
</Menu>

<Menu name="edit" noMerge="1"><text>&amp;Edit</text>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="delete"/>
</Menu>

<Menu name="settings">
 <Action name="show_removed"/>
 <Action name="show_hidden"/>
</Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true"><text>Main Toolbar</text>
 <Action name="newitem"/>
 <Action name="newsubmenu"/>
 <Separator/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="delete"/>
</ToolBar>

</kpartgui>
