<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kfontviewpart" version="1">
<ToolBar name="mainToolBar">
  <text>&amp;Main Toolbar</text>
  <Action name="changeText"/>
</ToolBar>
</kpartgui>

