# Default KSplash/ML Theme

[KSplash Theme: Default]
Name = KDE 3.4 Splash Screen
Description = KDE 3.4 Splash Screen based on the svg wallpaper (Lineart Logo)
Version = 1.0
Author = Jan-Victor Krille <jan-victor.krille@gmx.de>
Homepage = http://www.jan-victor.krille.de.vu

# Theme behaviour settings.
Engine = Default

# Should icons blink ala KDE, or not?
Icons Flashing = true
